CAPPr Docs
==========

CAPPr performs text classification. No training. No post-processing. **Just have your
LLM pick from a list of choices.** Or compute the probability of a completion given a
prompt. Squeeze more out of open source LLMs.

   | **C**\ompletion
   | **A**\fter
   | **P**\rompt
   | **Pr**\obability

.. note:: This package is in early stages, and the method needs to be evaluated on more
          datasets.


Get started
===========

.. toctree::
   :maxdepth: 2

   about


Get going
=========

.. toctree::
   :maxdepth: 2

   user_guide


Details
=======

.. toctree::
   :maxdepth: 2

   research


Package
=======

.. toctree::
   :maxdepth: 2

   cappr


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
